@@ -12,7 +12,7 @@ import unittest
 import jupyter_kernel_test as jkt
 
 from jupyter_client.manager import start_new_kernel
-from jupyter_kernel_test.messagespec import validate_message
+from jupyter_kernel_test import validate_message
 
 
 without_rich_display = '''\
@@ -59,7 +59,8 @@ class IRkernelTests(jkt.KernelTests):
         {'text': 'repr:::repr_png.def',    'matches': {'repr:::repr_png.default'}},
         {'text': 'repr::format2repr$mark', 'matches': {'repr::format2repr$markdown'}},
         {'text': 'load("test_i',           'matches': {'test_ir.py'}},
-        {'text': 'load("../test',          'matches': {'../testthat.Rout', '../testthat.R', '../testthat/'}},
+        {'text': 'load("./test_',          'matches': {'./test_utils.r', './test_kernel.r', './test_ir.py'}},
+        {'text': '.Last.v',                'matches': {'.Last.value'}},
     ]
 
     complete_code_samples = ['1', 'print("hello, world")', 'f <- function(x) {\n  x*2\n}']
@@ -299,7 +300,7 @@ class IRkernelTests(jkt.KernelTests):
         # Numeric constant
         test_token_is_ok('1')
         # Reserved word
-        test_token_is_ok('NULL')
+        # test_token_is_ok('NULL')  # null is not an object anymore?
         # Dataset with a help document
         test_token_is_ok('iris')
         # Function with a help document
